@@ -3,11 +3,14 @@ from aiohttp import ClientSession
 from json import load, dump
 from getpass import getpass
 
+from traceback import print_exc
+
 async def login():
     try:
         return await load_creds()
     except Exception as e:
         print(str(e))
+        print_exc()
         pass
     while True:
         server = input("Enter the server URL: ")
